/********************
*                   *
*   NeHeGL Header   *
*                   *
**********************************************************************************
*                                                                                *
*	You Need To Provide The Following Functions:                                 *
*                                                                                *
*	BOOL Initialize (GL_Window* window, Keys* keys);                             *
*		Performs All Your Initialization                                         *
*		Returns TRUE If Initialization Was Successful, FALSE If Not              *
*		'window' Is A Parameter Used In Calls To NeHeGL                          *
*		'keys' Is A Structure Containing The Up/Down Status Of keys              *
*                                                                                *
*	void Deinitialize (void);                                                    *
*		Performs All Your DeInitialization                                       *
*                                                                                *
*	void Update (DWORD milliseconds);                                            *
*		Perform Motion Updates                                                   *
*		'milliseconds' Is The Number Of Milliseconds Passed Since The Last Call  *
*		With Whatever Accuracy GetTickCount() Provides                           *
*                                                                                *
*	void Draw (void);                                                            *
*		Perform All Your Scene Drawing                                           *
*                                                                                *
*********************************************************************************/

#ifndef GL_FRAMEWORK__INCLUDED
#define GL_FRAMEWORK__INCLUDED

#define SCREEN_WIDTH 800
#define SCREEN_HEIGHT 600

#include <windows.h>								// Header File For Windows


class twodpoint { public:
	// A default constructor
	twodpoint() {}
	// This is our constructor that allows us to initialize our data upon creating an instance
	twodpoint(float X, float Y) 
	{ 
		x = X; y = Y;
	}
	// Here we overload the + operator so we can add vectors together 
	twodpoint operator+(twodpoint vVector)
	{
		// Return the added vectors result.
		return twodpoint(vVector.x + x, vVector.y + y);
	}
	// Here we overload the - operator so we can subtract vectors 
	twodpoint operator-(twodpoint vVector)
	{
		// Return the subtracted vectors result
		return twodpoint(x - vVector.x, y - vVector.y);
	}
	// Here we overload the * operator so we can multiply by scalars
	twodpoint operator*(float num)
	{
		// Return the scaled vector
		return twodpoint(x * num, y * num);
	}
	// Here we overload the / operator so we can divide by a scalar
	twodpoint operator/(float num)
	{
		// Return the scale vector
		return twodpoint(x / num, y / num);
	}
	GLfloat x, y;
};


class ppoint : public twodpoint { public:
	GLfloat ox,oy,radius,health,ohealth;
	bool hflip,vflip,onground,alive;
};
class playerpoint : public twodpoint { public:
	GLfloat ox,oy,radius,health,ohealth;
	bool hflip,vflip,onground,alive;
};

class cloudpoint : public twodpoint { public:
	GLfloat z,radius;
};

struct landpoint { public:
	// A default constructor
	landpoint() {}
	// This is our constructor that allows us to initialize our data upon creating an instance
	landpoint(float X, float Y) 
	{ 
		x = X; y = Y;
	}
	// Here we overload the + operator so we can add vectors together 
	landpoint operator+(landpoint vVector)
	{
		// Return the added vectors result.
		return landpoint(vVector.x + x, vVector.y + y);
	}
	// Here we overload the - operator so we can subtract vectors 
	landpoint operator-(landpoint vVector)
	{
		// Return the subtracted vectors result
		return landpoint(x - vVector.x, y - vVector.y);
	}
	// Here we overload the * operator so we can multiply by scalars
	landpoint operator*(float num)
	{
		// Return the scaled vector
		return landpoint(x * num, y * num);
	}
	// Here we overload the / operator so we can divide by a scalar
	landpoint operator/(float num)
	{
		// Return the scale vector
		return landpoint(x / num, y / num);
	}
	GLfloat x, y;
	bool next;
};

void lbpress(bool pressed);
void rbpress(bool pressed);

void twopoint( float& x1,float& y1,float& x2,float& y2,float dist, float k);

typedef struct {									// Structure For Keyboard Stuff
	BOOL keyDown [256];								// Holds TRUE / FALSE For Each Key
} Keys;													// Keys

typedef struct {									// Contains Information Vital To Applications
	HINSTANCE		hInstance;						// Application Instance
	const char*		className;						// Application ClassName
} Application;										// Application

typedef struct {									// Window Creation Info
	Application*		application;				// Application Structure
	char*				title;						// Window Title
	int					width;						// Width
	int					height;						// Height
	int					bitsPerPixel;				// Bits Per Pixel
	BOOL				isFullScreen;				// FullScreen?
} GL_WindowInit;									// GL_WindowInit

typedef struct {									// Contains Information Vital To A Window
	Keys*				keys;						// Key Structure
	HWND				hWnd;						// Window Handle
	HDC					hDC;						// Device Context
	HGLRC				hRC;						// Rendering Context
	GL_WindowInit		init;						// Window Init
	BOOL				isVisible;					// Window Visible?
	DWORD				lastTickCount;				// Tick Counter
} GL_Window;										// GL_Window

void TerminateApplication (GL_Window* window);		// Terminate The Application

void ToggleFullscreen (GL_Window* window);			// Toggle Fullscreen / Windowed Mode

// These Are The Function You Must Provide
BOOL Initialize (GL_Window* window, Keys* keys);	// Performs All Your Initialization

void Deinitialize (void);							// Performs All Your DeInitialization

void Update (DWORD milliseconds);					// Perform Motion Updates

void Draw (void);									// Perform All Your Scene Drawing

#endif												// GL_FRAMEWORK__INCLUDED
