/**************************************
*                                     *
*   Jeff Molofee's Basecode Example   *
*          nehe.gamedev.net           *
*                2001                 *
*                                     *
**************************************/

#include <windows.h>											// Header File For Windows
#include <stdio.h>
#include <stdlib.h>
#include <gl\gl.h>												// Header File For The OpenGL32 Library
#include <gl\glu.h>												// Header File For The GLu32 Library
#include <gl\glaux.h>											// Header File For The GLaux Library
#include "NeHeGL.h"												// Header File For NeHeGL
#include <math.h>

#pragma comment( lib, "opengl32.lib" )							// Search For OpenGL32.lib While Linking
#pragma comment( lib, "glu32.lib" )								// Search For GLu32.lib While Linking
#pragma comment( lib, "glaux.lib" )								// Search For GLaux.lib While Linking

#ifndef CDS_FULLSCREEN											// CDS_FULLSCREEN Is Not Defined By Some
#define CDS_FULLSCREEN 4										// Compilers. By Defining It This Way,
#endif															// We Can Avoid Errors

GL_Window*	g_window;
Keys*		g_keys;

// User Defined Variables
int pnum;
landpoint* land;
landpoint* aland;
landpoint* tland;
landpoint* atland;

#define mp -30.0f		//default ground distance
#define ground 0.36f*mp //default height of ground
float tmx, tmy,mx, my;
float campx;
bool lmb = 0,rmb = 0;
bool pflip = 0;
float xd,yd,td;

bool	key[256];
int i,r;
playerpoint playert, playerb, hand, blade;
#define mobnum 50
ppoint mob[mobnum];
cloudpoint cloud[10];

typedef struct													// Create A Structure
{
	GLubyte	*imageData;											// Image Data (Up To 32 Bits)
	GLuint	bpp;												// Image Color Depth In Bits Per Pixel.
	GLuint	width;												// Image Width
	GLuint	height;												// Image Height
	GLuint	texID;												// Texture ID Used To Select A Texture
} TextureImage;	
TextureImage textures[20];	
bool LoadTGA(TextureImage *texture, char *filename)				// Loads A TGA File Into Memory
{    
	GLubyte		TGAheader[12]={0,0,2,0,0,0,0,0,0,0,0,0};		// Uncompressed TGA Header
	GLubyte		TGAcompare[12];									// Used To Compare TGA Header
	GLubyte		header[6];										// First 6 Useful Bytes From The Header
	GLuint		bytesPerPixel;									// Holds Number Of Bytes Per Pixel Used In The TGA File
	GLuint		imageSize;										// Used To Store The Image Size When Setting Aside Ram
	GLuint		temp;											// Temporary Variable
	GLuint		type=GL_RGBA;									// Set The Default GL Mode To RBGA (32 BPP)

	FILE *file = fopen(filename, "rb");							// Open The TGA File

	if(	file==NULL ||											// Does File Even Exist?
		fread(TGAcompare,1,sizeof(TGAcompare),file)!=sizeof(TGAcompare) ||	// Are There 12 Bytes To Read?
		memcmp(TGAheader,TGAcompare,sizeof(TGAheader))!=0				||	// Does The Header Match What We Want?
		fread(header,1,sizeof(header),file)!=sizeof(header))				// If So Read Next 6 Header Bytes
	{
		if (file == NULL)										// Did The File Even Exist? *Added Jim Strong*
			return FALSE;										// Return False
		else													// Otherwise
		{
			fclose(file);										// If Anything Failed, Close The File
			return FALSE;										// Return False
		}
	}

	texture->width  = header[1] * 256 + header[0];				// Determine The TGA Width	(highbyte*256+lowbyte)
	texture->height = header[3] * 256 + header[2];				// Determine The TGA Height	(highbyte*256+lowbyte)
    
 	if(	texture->width	<=0	||									// Is The Width Less Than Or Equal To Zero
		texture->height	<=0	||									// Is The Height Less Than Or Equal To Zero
		(header[4]!=24 && header[4]!=32))						// Is The TGA 24 or 32 Bit?
	{
		fclose(file);											// If Anything Failed, Close The File
		return FALSE;											// Return False
	}

	texture->bpp	= header[4];								// Grab The TGA's Bits Per Pixel (24 or 32)
	bytesPerPixel	= texture->bpp/8;							// Divide By 8 To Get The Bytes Per Pixel
	imageSize		= texture->width*texture->height*bytesPerPixel;	// Calculate The Memory Required For The TGA Data

	texture->imageData=(GLubyte *)malloc(imageSize);			// Reserve Memory To Hold The TGA Data

	if(	texture->imageData==NULL ||								// Does The Storage Memory Exist?
		fread(texture->imageData, 1, imageSize, file)!=imageSize)	// Does The Image Size Match The Memory Reserved?
	{
		if(texture->imageData!=NULL)							// Was Image Data Loaded
			free(texture->imageData);							// If So, Release The Image Data

		fclose(file);											// Close The File
		return FALSE;											// Return False
	}

	for(GLuint i=0; i<int(imageSize); i+=bytesPerPixel)			// Loop Through The Image Data
	{															// Swaps The 1st And 3rd Bytes ('R'ed and 'B'lue)
		temp=texture->imageData[i];								// Temporarily Store The Value At Image Data 'i'
		texture->imageData[i] = texture->imageData[i + 2];		// Set The 1st Byte To The Value Of The 3rd Byte
		texture->imageData[i + 2] = temp;						// Set The 3rd Byte To The Value In 'temp' (1st Byte Value)
	}

	fclose (file);												// Close The File

	// Build A Texture From The Data
	glGenTextures(1, &texture[0].texID);						// Generate OpenGL texture IDs

	glBindTexture(GL_TEXTURE_2D, texture[0].texID);				// Bind Our Texture
	//glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);	// Linear Filtered
	//glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);	// Linear Filtered
	glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
	glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST);	// Linear Filtered
	

	if (texture[0].bpp==24)										// Was The TGA 24 Bits
	{
		type=GL_RGB;											// If So Set The 'type' To GL_RGB
	}

	//glTexImage2D(GL_TEXTURE_2D, 0, type, texture[0].width, texture[0].height, 0, type, GL_UNSIGNED_BYTE, texture[0].imageData);
	gluBuild2DMipmaps(GL_TEXTURE_2D, 4, texture[0].width, texture[0].height, type, GL_UNSIGNED_BYTE, texture[0].imageData);
	return true;	
}




void collideline(float i1x, float i1y, float i2x, float i2y, float& cx, float& cy, float radius, float ox, float oy, float swapped, bool& onground){

float cnum, snum, xdist, ydist, tdist;
xdist = i2x - i1x;
ydist = i2y - i1y;
        
tdist = sqrt(xdist * xdist + ydist * ydist);
//If tdist = 0 Then tdist = 0.0001
cnum = (xdist / tdist) * swapped;
snum = (ydist / tdist) * swapped;

float PX, PY;
PX = (-snum) * radius;
PY = (cnum) * radius;

float crx, cry;
crx = cx + PX;
cry = cy + PY;
float opcy, opcx;
opcx = cx - PX;
opcy = cy - PY;

float ua, ub;
ua = ((crx - opcx) * (i1y - opcy) - (cry - opcy) * (i1x - opcx)) / ((cry - opcy) * (i2x - i1x) - (crx - opcx) * (i2y - i1y));
ub = ((i2x - i1x) * (i1y - opcy) - (i2y - i1y) * (i1x - opcx)) / ((cry - opcy) * (i2x - i1x) - (crx - opcx) * (i2y - i1y));

if (ua >= 0 && ua <= 1 && ub >= 0 && ub <= 1) {
    
    float ix, iy;
    ix = i1x + ua * (i2x - i1x);
    iy = i1y + ua * (i2y - i1y);
    
    float fx, fy;
    fx = ix - PX;
    fy = iy - PY;
    
	onground = 1;
    /*float motionx, motiony;
        motionx = fx - ox;
        motiony = fy - oy;*/


        //FWOG = 1;
        //fwtimer = 5;
        cx = fx;
        cy = fy;
        //LandPX = -snum;
        //LandPY = cnum;  
	/*if (part != 3 And part != 4) {
        cx = ox + (motionx * 0)
        cy = oy + (motiony * 0)
	}*/
    /*If frmcontrols.chkjelly = 1 Then
    i1x = i1x + (ix - ox) / 5
    i1y = i1y + (iy - oy) / 5
    i2x = i2x + (ix - ox) / 5
    i2y = i2y + (iy - oy) / 5
    End If*/

	}
}

BOOL Initialize (GL_Window* window, Keys* keys)					// Any GL Init Code & User Initialiazation Goes Here
{
	g_window	= window;
	g_keys		= keys;

	// Start Of User Initialization

	glClearColor (0.0f, 0.0f, 0.0f, 0.5f);						// Black Background
	glClearDepth (1.0f);										// Depth Buffer Setup
	glDepthFunc (GL_LEQUAL);									// The Type Of Depth Testing (Less Or Equal)
	glEnable (GL_DEPTH_TEST);									// Enable Depth Testing
	glShadeModel (GL_SMOOTH);									// Select Smooth Shading
	glHint (GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);			// Set Perspective Calculations To Most Accurate


	glClearDepth(1.0f);											// Depth Buffer Setup
	glDepthFunc(GL_LEQUAL);										// Type Of Depth Testing
	glEnable(GL_DEPTH_TEST);									// Enable Depth Testing
	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);			// Enable Alpha Blending (disable alpha testing)
	glEnable(GL_BLEND);											// Enable Blending       (disable alpha testing)
	glAlphaFunc(GL_GREATER,0.1f);								// Set Alpha Testing     (disable blending)
	glEnable(GL_ALPHA_TEST);									// Enable Alpha Testing  (disable blending)
	glEnable(GL_TEXTURE_2D);									// Enable Texture Mapping
	glEnable(GL_CULL_FACE);	

	ShowCursor(false);

	LoadTGA(&textures[0],"Data/head.tga");
	LoadTGA(&textures[1],"Data/Ground.tga");
	LoadTGA(&textures[2],"Data/foot.tga");
	LoadTGA(&textures[3],"Data/sheep.tga");
	LoadTGA(&textures[4],"Data/pointer.tga");
	LoadTGA(&textures[5],"Data/sky.tga");
	LoadTGA(&textures[6],"Data/HANDLE.tga");
	LoadTGA(&textures[7],"Data/STICK.tga");
	LoadTGA(&textures[8],"Data/BALL.tga");
	LoadTGA(&textures[10],"Data/cloud1.tga");
	LoadTGA(&textures[11],"Data/cloud2.tga");
	LoadTGA(&textures[12],"Data/cloud3.tga");
	LoadTGA(&textures[13],"Data/cloud4.tga");
	LoadTGA(&textures[14],"Data/cloud5.tga");
	LoadTGA(&textures[15],"Data/cloud6.tga");
	LoadTGA(&textures[16],"Data/cloud7.tga");
	LoadTGA(&textures[17],"Data/cloud8.tga");
	LoadTGA(&textures[18],"Data/body.tga");

	playert.x = playert.ox = 0;
	playert.y = playert.oy = 0;
	playert.radius = 1.0f;

	playerb.x = playerb.ox = 0;
	playerb.y = playerb.oy = -1;
	playerb.radius = 0.7f;

	hand.x = hand.ox = 1;
	hand.y = hand.oy = 0;
	hand.radius = 0.3f;

	blade.x = blade.ox = 1;
	blade.y = blade.oy = -1;
	blade.radius = 0.8f;



	for (i = 0; i < mobnum; i++) {
		
		mob[i].x = mob[i].ox = (float)rand()/RAND_MAX*10;
		mob[i].y = mob[i].oy = (float)rand()/RAND_MAX*10;
		mob[i].radius = 1;
		mob[i].health = 5;

	}

	for (i = 0; i < 10; i++) {
		
		cloud[i].x  = (float)rand()/RAND_MAX*300;
		cloud[i].y  = (float)rand()/RAND_MAX*15;
		cloud[i].radius = 10;
		cloud[i].z = mp+(float)rand()/RAND_MAX*mp*2;

	}

FILE 	*LoadFile;
			char 	FileName[] = "MyGame.svg";

			LoadFile = fopen (FileName, "rb"); // opens file for reading and in binary mode

			if (LoadFile == NULL)
			{ 
			MessageBox (HWND_DESKTOP, "Error: couldnt load the file", "Error", MB_OK | MB_ICONEXCLAMATION);
			}
			char  SIGNATURE[4];

			fread (SIGNATURE, sizeof (char), 4, LoadFile);

			// you should check the signature to see if is equal to LSD

			fread (&pnum, sizeof(int), 1, LoadFile);
			
			

			delete[] land;
			delete[] aland;
			land = new landpoint[pnum];
			aland = new landpoint[pnum];

			fread (land, sizeof (landpoint), pnum, LoadFile);
			fread (aland, sizeof (landpoint), pnum, LoadFile);

			fclose (LoadFile);

	


	return TRUE;												// Return TRUE (Initialization Successful)
}

void Deinitialize (void)										// Any User DeInitialization Goes Here
{
}
void twopoint(float& x1,float& y1,float& x2,float& y2,float dist, float k) {
	GLfloat xd = x1-x2;
	GLfloat yd = y1-y2;
	GLfloat td = sqrtf(xd*xd+yd*yd);
	GLfloat diffdist = dist-td;
	diffdist *=k;
	xd=xd/td*diffdist;
	yd=yd/td*diffdist;
	x1 += xd;
	y1 += yd;
	x2 -= xd;
	y2 -= yd;
}

void lbpress(bool pressed) {
	lmb = pressed;
}
void rbpress(bool pressed) {
	rmb = pressed;
}
void Update (DWORD milliseconds)								// Perform Motion Updates Here
{

POINT mousePos;									// This is a window structure that holds an X and Y
	int middleX = SCREEN_WIDTH  >> 1;				// This is a binary shift to get half the width
	int middleY = SCREEN_HEIGHT >> 1;				// This is a binary shift to get half the height
	float angleY = 0.0f;							// This is the direction for looking up or down
	float angleZ = 0.0f;							// This will be the value we need to rotate around the Y axis (Left and Right)
	static float currentRotX = 0.0f;
	GetCursorPos(&mousePos);						
	SetCursorPos(middleX, middleY);							
	tmx -= (float)(middleX - mousePos.x);
	tmy += (float)(middleY - mousePos.y);	
	if (tmx < -170.0f) {tmx = -170.0f;}
	if (tmx > 170.0f) {tmx = 170.0f;}
	if (tmy < -130.0f) {tmy = -130.0f;}
	if (tmy > 130.0f) {tmy = 130.0f;}
	mx = campx+(tmx)/10.0f;
	my = tmy/10.0f;

	static bool aj, onground, nothing;
	float jumpy = 1.0f, antigrav = 0.125f,grav = -0.1f;
	if (!onground || (g_keys->keyDown ['S'] || g_keys->keyDown [VK_DOWN])) {antigrav = 0.005f; grav = -0.07f;}
	if (g_keys->keyDown [VK_LEFT] || g_keys->keyDown ['A']) {
		playerb.x -= 0.08f*onground+0.02f;
		pflip = 1;
	}
	if (g_keys->keyDown [VK_RIGHT] || g_keys->keyDown ['D']) {
		playerb.x += 0.08f*onground+0.02f;
		pflip = 0;
	}
	if (g_keys->keyDown [VK_DOWN] || g_keys->keyDown ['S']) {
		jumpy *= 0.5f;
	}
	if (g_keys->keyDown ['W'] || g_keys->keyDown [VK_UP]) {
		antigrav +=0.23f; grav -=0.1f;
		//playert.y +=milliseconds/10;
	}
	if (g_keys->keyDown [VK_SPACE]) {
		jumpy *= 1.8f;
		if (aj && onground) {
			playert.y+=1.2f;
			hand.y+=1.3f;
			blade.y+=1.3f;
		}
		aj = 0;
	}
	if (!g_keys->keyDown [VK_SPACE]) {
		aj = 1;
	}
	if (lmb) {
		xd = mx-blade.x;
		yd = my-blade.y;
		td = sqrt(xd*xd+yd*yd)*5;
			xd /= td;
			yd /= td;
		if (td > 20) {  
			playert.x -= xd;
			playert.y -= yd;
		} else {
			xd /= 5;
			yd /= 5;
		}
	blade.x += xd;
	blade.y += yd;
	}
	if (rmb) {
		xd = mx-playert.x;
		yd = my-playert.y;
		td = sqrt(xd*xd+yd*yd)*5;
		xd /= td;
		yd /= td;
		blade.x += -yd;
		blade.y += xd;
		hand.x -= -yd;
		hand.y -= xd;
		hand.x += xd;
		hand.y += yd;
		playert.x -= xd;
		playert.y -= yd;
	}


	xd = (playert.x-playert.ox);//*(milliseconds/40);
	yd = (playert.y-playert.oy);//*(milliseconds/40);
	playert.x+=xd*1.0f+((float)rand()/RAND_MAX/100)-0.005f;
	playert.y+=yd*1.0f+grav+antigrav+((float)rand()/RAND_MAX/100)-0.005f;
	playert.ox+=xd;
	playert.oy+=yd;
	xd = playerb.x-playerb.ox;
	yd = playerb.y-playerb.oy;
	playerb.x+=xd*(0.8f+(0.15f-0.15f*onground));
	playerb.y+=yd*0.8f+grav;
	playerb.ox+=xd;
	playerb.oy+=yd;
	xd = hand.x-hand.ox;
	yd = hand.y-hand.oy;
	hand.x+=xd*1.0f;
	hand.y+=yd*1.0f+grav/10;
	hand.ox+=xd;
	hand.oy+=yd;
	xd = blade.x-blade.ox;
	yd = blade.y-blade.oy;
	blade.x+=xd*1.0f;
	blade.y+=yd*1.0f+grav/10;
	blade.ox+=xd;
	blade.oy+=yd;

	for (i = 0; i < mobnum; i++) {
		xd = mob[i].x-mob[i].ox+((float)rand()/RAND_MAX/5)-0.1f;
		yd = mob[i].y-mob[i].oy+((float)rand()/RAND_MAX/5)-0.1f;
		mob[i].x+=xd*0.95f;
		mob[i].y+=yd*0.95f+grav/10;
		mob[i].ox+=xd;
		mob[i].oy+=yd;
		if (rand()*100/RAND_MAX == 5) {
			mob[i].y+= 0.3f;
		}
	}

	twopoint(playert.x,playert.y,playerb.x,playerb.y,(playert.radius+playerb.radius)*jumpy, 0.3f);
	twopoint(playert.x,playert.y,hand.x,hand.y,1,0.3f);
	twopoint(hand.x,hand.y,blade.x,blade.y,2,0.3f);
	onground = 0;

	for (i = 0 ; i<pnum-1;i++){
	collideline(land[i].x, land[i].y, land[i+1].x, land[i+1].y, playerb.x, playerb.y, playerb.radius, playerb.ox, playerb.oy, -1,onground);
	collideline(land[i].x, land[i].y, land[i+1].x, land[i+1].y, playert.x, playert.y, playert.radius, playert.ox, playert.oy, -1,nothing);
	collideline(land[i].x, land[i].y, land[i+1].x, land[i+1].y, blade.x, blade.y, blade.radius, blade.ox, blade.oy, -1,nothing);
	}
	if (playert.y < ground+playert.radius) {playert.y = ground+playert.radius;}
	if (playerb.y < ground+playerb.radius) {playerb.y = ground+playerb.radius; onground = 1;}
	if (hand.y < ground+hand.radius) {hand.y = ground+hand.radius;}
	if (blade.y < ground+blade.radius) {blade.y = ground+blade.radius;}

	for (i = 0; i < mobnum; i++) {
		if (mob[i].y < ground+mob[i].radius) {
			mob[i].y -= (mob[i].y-mob[i].oy)*2;
			if (mob[i].y < ground+mob[i].radius) {
				mob[i].y = ground+mob[i].radius;
			}
		}
		for (int r = 0; r<pnum-1;r++){
			collideline(land[r].x, land[r].y, land[r+1].x, land[r+1].y, mob[i].x, mob[i].y, mob[i].radius, mob[i].ox, mob[i].oy, -1,nothing);
		}
		xd = mob[i].x - playert.x;
		yd = mob[i].y - playert.y;
		td = sqrt(xd*xd+yd*yd);
		if (td < mob[i].radius+playert.radius) {
			twopoint(mob[i].x,mob[i].y,playert.x,playert.y,mob[i].radius+playert.radius,0.4f);
		}
		xd = mob[i].x - playerb.x;
		yd = mob[i].y - playerb.y;
		td = sqrt(xd*xd+yd*yd);
		if (td < mob[i].radius+playerb.radius) {
			onground = 1;
			twopoint(mob[i].x,mob[i].y,playerb.x,playerb.y,mob[i].radius+playerb.radius,0.4f);
		}
		xd = mob[i].x - blade.x; 
		yd = mob[i].y - blade.y;
		td = sqrt(xd*xd+yd*yd);
		if (td < mob[i].radius+blade.radius) {
			GLfloat force, xfm, yfm,xfp,yfp,fx,fy;
			xfm = (mob[i].x)-(mob[i].ox);
			yfm = (mob[i].y)-(mob[i].oy);
			xfp = (blade.x)-(blade.ox);
			yfp = (blade.y)-(blade.oy);
			fx = (xfp-xfm);
			fy = (yfp-yfm);
			force = fx*fx+fy*fy;
			//force = ((mob[i].x)-(mob[i].ox))-((blade.x)-(blade.ox))+((mob[i].y)-(mob[i].oy))-((blade.y)-(blade.oy));
			mob[i].health -= force*10;
			twopoint(mob[i].x,mob[i].y,blade.x,blade.y,(mob[i].radius+blade.radius)*2.3,0.4f);
		}

		if (mob[i].health < 0) {
			mob[i].x = mob[i].ox = (float)rand()/RAND_MAX*10;
			mob[i].y = mob[i].oy = (float)rand()/RAND_MAX*10;
			mob[i].health = 5;
		}

	}
	for (i = 0; i < mobnum-1; i++) {
		for (r = i+1; r < mobnum; r++) {
			GLfloat xd = mob[i].x - mob[r].x;
			GLfloat yd = mob[i].y - mob[r].y;
			GLfloat td = xd*xd+yd*yd;
			float rad = mob[i].radius+mob[r].radius;
			if (td < rad*rad) {
			GLfloat td = sqrtf(td);
				twopoint(mob[i].x,mob[i].y,mob[r].x,mob[r].y,mob[i].radius+mob[r].radius,0.4f);
			}
		}
	}

}
void drawquad(float x, float y, float z, float w, float h, int texid) {
	glBindTexture(GL_TEXTURE_2D, textures[texid].texID);
	glBegin (GL_QUADS);	
		glTexCoord2f(0.0f, 1.0f);glVertex3f(x-w ,y+h, z);
		glTexCoord2f(0.0f, 0.0f);glVertex3f(x-w ,y-h, z);
		glTexCoord2f(1.0f, 0.0f);glVertex3f(x+w ,y-h, z);
		glTexCoord2f(1.0f, 1.0f);glVertex3f(x+w ,y+h, z);
	glEnd();
}



void Draw (void)
{
	glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);		// Clear Screen And Depth Buffer
	glLoadIdentity ();											// Reset The Modelview Matrix

	xd = playert.x-campx;
	campx += xd*0.58f;
	//campx = playert.x*2-campx;
	glTranslatef(-campx,0,0);
	//campx = playert.x*2-campx;
	

	drawquad(campx,0,mp*3,100,100,5);

		for (i = 0; i < 10; i++) {
		drawquad(cloud[i].x,cloud[i].y,cloud[i].z,cloud[i].radius,cloud[i].radius,(int)(i*0.8+10));
	}

	glBindTexture(GL_TEXTURE_2D, textures[1].texID);
	for (i=0;i<pnum-1;i++) {
	glBegin (GL_QUADS);	
					glTexCoord2f(0.0f, 1.0f);glVertex3f(land[i].x,land[i].y, mp);
					glTexCoord2f(0.0f, 0.0f);glVertex3f(aland[i].x,aland[i].y, mp);
					glTexCoord2f(1.0f, 0.0f);glVertex3f(aland[i+1].x,aland[i+1].y, mp);
					glTexCoord2f(1.0f, 1.0f);glVertex3f(land[i+1].x,land[i+1].y, mp);
	glEnd();
	}
	drawquad(playerb.x,playerb.y,mp,playerb.radius,playerb.radius,2);
	
	GLfloat bw = 0.5f; 
	 xd = hand.x - blade.x;
	 yd = hand.y - blade.y;
	 td = sqrtf(xd*xd+yd*yd)/bw;
	xd/=td;
	yd/=td;
	glBindTexture(GL_TEXTURE_2D, textures[7].texID);
	glBegin (GL_QUADS);	
		glTexCoord2f(0.0f, 1.0f);glVertex3f(blade.x+yd ,blade.y-xd, mp);
		glTexCoord2f(0.0f, 0.0f);glVertex3f(hand.x+yd ,hand.y-xd, mp);
		glTexCoord2f(1.0f, 0.0f);glVertex3f(hand.x-yd ,hand.y+xd, mp);
		glTexCoord2f(1.0f, 1.0f);glVertex3f(blade.x-yd ,blade.y+xd, mp);
	glEnd();


	xd = playerb.x - playert.x;
	 yd = playerb.y - playert.y;
	 td = sqrtf(xd*xd+yd*yd);
	xd/=td;
	yd/=td;
	glBindTexture(GL_TEXTURE_2D, textures[18].texID);
	glBegin (GL_QUADS);	
		glTexCoord2f(0.0f, 1.0f);glVertex3f(playert.x+yd ,playert.y-xd, mp);
		glTexCoord2f(0.0f, 0.0f);glVertex3f(playerb.x+yd ,playerb.y-xd, mp);
		glTexCoord2f(1.0f, 0.0f);glVertex3f(playerb.x-yd ,playerb.y+xd, mp);
		glTexCoord2f(1.0f, 1.0f);glVertex3f(playert.x-yd ,playert.y+xd, mp);
	glEnd();

	
	drawquad(blade.x,blade.y,mp,blade.radius*1.5f,blade.radius*1.5f,8);
	drawquad(hand.x,hand.y,mp,hand.radius,hand.radius,6);


	xd = playerb.x - playert.x;
	yd = playerb.y - playert.y;
	td = sqrtf(xd*xd+yd*yd)*playert.radius;
	xd/=td;
	yd/=td;
	glBindTexture(GL_TEXTURE_2D, textures[0].texID);
	if (pflip) { //flip texture
	glBegin (GL_QUADS);	
		/*br*/glTexCoord2f(1.0f, 1.0f);glVertex3f(playert.x+yd-xd ,playert.y-yd-xd, mp);
		/*bl*/glTexCoord2f(1.0f, 0.0f);glVertex3f(playert.x+yd+xd ,playert.y+yd-xd, mp);
		/*tl*/glTexCoord2f(0.0f, 0.0f);glVertex3f(playert.x-yd+xd ,playert.y+yd+xd, mp);
		/*tr*/glTexCoord2f(0.0f, 1.0f);glVertex3f(playert.x-yd-xd ,playert.y-yd+xd, mp);
	glEnd();
	} else {
	glBegin (GL_QUADS);	
		/*br*/glTexCoord2f(0.0f, 1.0f);glVertex3f(playert.x+yd-xd ,playert.y-yd-xd, mp);
		/*bl*/glTexCoord2f(0.0f, 0.0f);glVertex3f(playert.x+yd+xd ,playert.y+yd-xd, mp);
		/*tl*/glTexCoord2f(1.0f, 0.0f);glVertex3f(playert.x-yd+xd ,playert.y+yd+xd, mp);
		/*tr*/glTexCoord2f(1.0f, 1.0f);glVertex3f(playert.x-yd-xd ,playert.y-yd+xd, mp);
	glEnd();
	}
	
	for (i = 0; i < mobnum; i++) {
		yd = (playert.x - mob[i].x);
		xd = -(playert.y - mob[i].y);
		td = sqrtf(xd*xd+yd*yd)*mob[i].radius;
		mob[i].vflip = 0;
		if (yd > 0) {
			mob[i].vflip = 1;
		}
		glBindTexture(GL_TEXTURE_2D, textures[3].texID);
		if (td < 10) {
			xd/=td;
			yd/=td;
			if (!mob[i].vflip) { //flip texture
				glBegin (GL_QUADS);	
					glTexCoord2f(0.0f, 1.0f);glVertex3f(mob[i].x+yd-xd ,mob[i].y-yd-xd, mp);
					glTexCoord2f(0.0f, 0.0f);glVertex3f(mob[i].x+yd+xd ,mob[i].y+yd-xd, mp);
					glTexCoord2f(1.0f, 0.0f);glVertex3f(mob[i].x-yd+xd ,mob[i].y+yd+xd, mp);
					glTexCoord2f(1.0f, 1.0f);glVertex3f(mob[i].x-yd-xd ,mob[i].y-yd+xd, mp);
				glEnd();
				} else {
				glBegin (GL_QUADS);	
					glTexCoord2f(0.0f, 0.0f);glVertex3f(mob[i].x+yd-xd ,mob[i].y-yd-xd, mp);
					glTexCoord2f(0.0f, 1.0f);glVertex3f(mob[i].x+yd+xd ,mob[i].y+yd-xd, mp);
					glTexCoord2f(1.0f, 1.0f);glVertex3f(mob[i].x-yd+xd ,mob[i].y+yd+xd, mp);
					glTexCoord2f(1.0f, 0.0f);glVertex3f(mob[i].x-yd-xd ,mob[i].y-yd+xd, mp);
				glEnd();
			}
		} else {
			drawquad(mob[i].x,mob[i].y,mp-0.5,mob[i].radius,mob[i].radius,3);
		}
	}
	
	glBlendFunc(GL_ONE, GL_ONE);
	glDisable(GL_TEXTURE_2D);


	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);			// Enable Alpha Blending (disable alpha testing)
	glEnable(GL_TEXTURE_2D);									// Enable Texture Mapping

	static int r,g,b;
	int adam = 15;
	if (r+g+b ==0) {
		r=255;
		g=0;
		b=0;
	}
	if (r==255 && b == 0) {
		g+=adam;
	}
	if (g==255 && b ==0) {
		r-=adam;
	}
	if (g==255 && r ==0) {
		b+=adam;
	}
	if (b == 255 && r == 0) {
		g-=adam;
	}
	if (b==255 && g ==0) {
		r+=adam;
	}
	if (r == 255 && g==0){
		b-=adam;
	}

	glColor3ub(r, g, b);	
	drawquad(mx,my,mp,2,2,4);	
	glColor3ub(255, 255, 255);	

	glFlush ();													// Flush The GL Rendering Pipeline
}
